@@ -2,7 +2,7 @@ package Hades::Macro::Dolos;
 use strict;
 use warnings;
 use base qw/Hades::Macro/;
-our $VERSION = 0.23;
+our $VERSION = 0.24;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
@@ -569,7 +569,7 @@ Hades::Macro::Dolos - Hades macro helpers for Dolos
 
 =head1 VERSION
 
-Version 0.01
+Version 0.24
 
 =cut
 
@@ -772,20 +772,12 @@ You can find documentation for this module with the perldoc command.
 
 You can also look for information at:
 
-=over 4
+=over 2
 
 =item * RT: CPAN's request tracker (report bugs here)
 
 L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Hades-Macro-Dolos>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Hades-Macro-Dolos>
-
-=item * CPAN Ratings
-
-L<https://cpanratings.perl.org/d/Hades-Macro-Dolos>
-
 =item * Search CPAN
 
 L<https://metacpan.org/release/Hades-Macro-Dolos>
